@@ -15,7 +15,7 @@
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the
  * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Boston, MA 02110-1301, USA.
  *
  * In addition, as a special exception, Dom Lachowicz
  * gives permission to link the code of this program with
@@ -264,7 +264,7 @@ EnchantPWL* enchant_pwl_init_with_file(const char * file)
 
 	g_return_val_if_fail (file != NULL, NULL);
 
-	fd = enchant_fopen(file, "wb");
+	fd = enchant_fopen(file, "ab+");
 	if(fd == NULL)
 		{
 			return NULL;
@@ -331,7 +331,7 @@ static void enchant_pwl_refresh_from_file(EnchantPWL* pwl)
 					continue;
 				}
 						
-			if( line[0] != '#')
+			if( line[0] && line[0] != '#')
 				{
 					if(g_utf8_validate(line, -1, NULL))
 						enchant_pwl_add_to_trie(pwl, line, strlen(line));
@@ -676,7 +676,7 @@ static void enchant_pwl_case_and_denormalize_suggestions(EnchantPWL *pwl,
 
 			suggestion = g_hash_table_lookup (pwl->words_in_trie, suggs_list->suggs[i]);
 			suggestion_len = strlen(suggestion);
-			
+
 			if(utf8_case_convert_function &&
 					!enchant_is_all_caps(suggestion, suggestion_len))
 				{
